gantt.i18n.setLocale("ru");
gantt.config.xml_date = "%Y-%m-%d %H:%i:%s";

gantt.config.order_branch = true;
gantt.config.order_branch_free = true;

gantt.config.work_time = true;
gantt.config.correct_work_time = true;


gantt.config.min_column_width = 50;
gantt.config.duration_unit = "day";
gantt.config.scale_height = 20 * 3;


// Левая панель
gantt.config.columns = [
    { name: "text", label: "Задача", tree: true, width: '230' },
    { name: "start_date", label: "Начало", align: "center", template: function(obj) { return "<small>" + gantt.date.date_to_str("%d.%m.%Y")(obj.start_date) + "</small>" } },
    { name: "duration", label: "Дней", align: "center" },
    { name: "add", label: "" }
];


// Раскрасить ячейки выходных в таймлайне и хеадере 
gantt.templates.timeline_cell_class = function(item, date) {
    if (!gantt.isWorkTime(date)) {
        return "weekend"
    }
};

var daysStyle = function(date) {
    if (!gantt.isWorkTime(date)) { return "weekend" }
};


// Лайтбокс
gantt.locale.labels["section_priority"] = "Цвет";
gantt.locale.labels["type_milestone"] = "Веха";
gantt.locale.labels["type_project"] = "Проект";
gantt.locale.labels["type_task"] = "Задача";
gantt.locale.labels["section_time"] = "Дата";

var colors = [
    { key: "", label: "Стандартный" },
    { key: "#4B0082", label: "Индиго" },
    { key: "#B0C4DE", label: "Светло-голубой" },
    { key: "#32CD32", label: "Лайм" },
    { key: "#7B68EE", label: "Голубой" },
    { key: "#FFA500", label: "Оранжевый" },
    { key: "#FF4500", label: "Красный" }
]

gantt.config.lightbox.sections = [
    { name: "description", height: 70, map_to: "text", type: "textarea", focus: true },
    { name: "type", type: "typeselect", map_to: "type" },
    { name: "priority", height: 22, map_to: "color", type: "select", options: colors },
    { name: "time", type: "time", map_to: "auto" },
];

gantt.config.lightbox["project_sections"] = [
    { name: "description", height: 70, map_to: "text", type: "textarea", focus: true },
    { name: "type", type: "typeselect", map_to: "type" },
    { name: "priority", height: 22, map_to: "color", type: "select", options: colors },
]

gantt.config.lightbox["milestone_sections"] = [
    { name: "description", height: 70, map_to: "text", type: "textarea", focus: true },
    { name: "type", type: "typeselect", map_to: "type" },
    { name: "priority", height: 22, map_to: "color", type: "select", options: colors },
    { name: "time", type: "duration", map_to: "auto", single_date: true },
];


// Плагин МАРКЕР. Вертикальная линия - сегодншний день
gantt.plugins({
    marker: true
});
var dateToStr = gantt.date.date_to_str(gantt.config.task_date);
var today = new Date();
gantt.addMarker({
    start_date: today,
    css: "today",
    text: "Сегодня",
    title: "Сегодня: " + dateToStr(today)
});


// Плагин ВСПЛЫВАЮЩАЯ ПОДСКАЗКА
gantt.plugins({
    tooltip: true
});
gantt.attachEvent("onGanttReady", function() {
    var tooltips = gantt.ext.tooltips;
    tooltips.tooltip.setViewport(gantt.$task_data);
});
gantt.templates.tooltip_text = function(start, end, task) {
    var type = gantt.locale.labels["type_" + task.type];
    var text = "<b>" + type + ":</b> " + task.text + "<br/><b>Продолжительность:</b> " + task.duration + " дней<br/><b>Начало: </b>" + dateToStr(start) + " <br/><b>Окончание: </b>" + dateToStr(end);
    if (task.type == "milestone") text = "<b>" + type + ":</b> " + task.text + "<br/><b>Дата: </b>" + dateToStr(start);
    return text;
};


// Плагин ZOOM. Масштабирование таймлана мышью CTRL+WHEEL
var zoomConfig = {
    minColumnWidth: 50,
    maxColumnWidth: 150,
    levels: [
        [
            { unit: "year", format: "%Y", step: 1 },
            { unit: "month", format: "%M", step: 1 }
        ],
        [
            { unit: "month", format: "%M %Y", step: 1 },
            {
                unit: "week",
                step: 1,
                format: function(date) {
                    var dateToStr = gantt.date.date_to_str("%d %M");
                    var endDate = gantt.date.add(date, -6, "day");
                    return dateToStr(date) + " - " + dateToStr(endDate);
                }
            }
        ],
        [
            { unit: "month", step: 1, format: "%F, %Y" },
            { unit: "day", step: 1, format: "%D, %d", css: daysStyle }
        ],
    ],
    useKey: "ctrlKey",
    trigger: "wheel",
    activeLevelIndex: 2,
    element: function() {
        return gantt.$root.querySelector(".gantt_task");
    }
}
gantt.ext.zoom.init(zoomConfig);


// Плагин перемещения таймлайна мышью
gantt.plugins({
    drag_timeline: true
});


// Иницализация и загрузка данных
gantt.init("gantt");
gantt.load("/data");

// CRUD Интерфейс к бэку для задач и линков
var dataProcessor = new gantt.dataProcessor("/data");
dataProcessor.init(gantt);
dataProcessor.setTransactionMode("REST");